@@ -1,9 +1,48 @@
-/* read_pwd.c */
-/* Copyright (C) 1995 Eric Young (eay@mincom.oz.au).
+/* lib/des/read_pwd.c */
+/* Copyright (C) 1995 Eric Young (eay@mincom.oz.au)
  * All rights reserved.
+ * 
+ * This file is part of an SSL implementation written
+ * by Eric Young (eay@mincom.oz.au).
+ * The implementation was written so as to conform with Netscapes SSL
+ * specification.  This library and applications are
+ * FREE FOR COMMERCIAL AND NON-COMMERCIAL USE
+ * as long as the following conditions are aheared to.
+ * 
  * Copyright remains Eric Young's, and as such any Copyright notices in
- * the code are not to be removed.
- * See the COPYRIGHT file in the libdes distribution for more details.
+ * the code are not to be removed.  If this code is used in a product,
+ * Eric Young should be given attribution as the author of the parts used.
+ * This can be in the form of a textual message at program startup or
+ * in documentation (online or textual) provided with the package.
+ * 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 3. All advertising materials mentioning features or use of this software
+ *    must display the following acknowledgement:
+ *    This product includes software developed by Eric Young (eay@mincom.oz.au)
+ * 
+ * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ * 
+ * The licence and distribution terms for any publically available version or
+ * derivative of this code cannot be changed.  i.e. this code cannot simply be
+ * copied and put under another distribution licence
+ * [including the GNU Public Licence.]
  */
 
 /* 06-Apr-92 Luke Brennan    Support for VMS */
@@ -26,8 +65,12 @@
 #include <termio.h>
 #define sgttyb termio
 #define sg_flags c_lflag
+#ifndef TIOCGETP
 #define TIOCGETP TCGETA
+#endif
+#ifndef TIOCSETP
 #define TIOCSETP TCSETA
+#endif
 #else /* !TERMIO */
 #include <sgtty.h>
 #endif
@@ -35,6 +78,7 @@
 #include <sys/ioctl.h>
 #endif
 #else /* MSDOS */
+#include <conio.h>
 #define fgets(a,b,c) noecho_fgets(a,b,c)
 #endif
 #else /* VMS */
@@ -52,6 +96,16 @@ struct IOSB {
 #define NX509_SIG 32
 #endif
 
+#ifdef PROTO
+static void read_till_nl(FILE *);
+static int read_pw(char *buf, char *buff, int size, char *prompt, int verify);
+static void recsig(int);
+static void pushsig(void);
+static void popsig(void);
+#ifdef MSDOS
+static int noecho_fgets(char *buf, int size, FILE *tty);
+#endif
+#else
 static void read_till_nl();
 static int read_pw();
 static void recsig();
@@ -60,12 +114,13 @@ static void popsig();
 #ifdef MSDOS
 static int noecho_fgets();
 #endif
+#endif
 
 static void (*savsig[NX509_SIG])();
 static jmp_buf save;
 
-int des_read_password(key,prompt,verify)
-des_cblock *key;
+int des_read_password(key, prompt, verify)
+des_cblock (*key);
 char *prompt;
 int verify;
 	{
@@ -74,14 +129,14 @@ int verify;
 
 	if ((ok=read_pw(buf,buff,BUFSIZ,prompt,verify)) == 0)
 		des_string_to_key(buf,key);
-	bzero(buf,BUFSIZ);
-	bzero(buff,BUFSIZ);
+	memset(buf,0,BUFSIZ);
+	memset(buff,0,BUFSIZ);
 	return(ok);
 	}
 
-int des_read_2passwords(key1,key2,prompt,verify)
-des_cblock *key1;
-des_cblock *key2;
+int des_read_2passwords(key1, key2, prompt, verify)
+des_cblock (*key1);
+des_cblock (*key2);
 char *prompt;
 int verify;
 	{
@@ -90,12 +145,12 @@ int verify;
 
 	if ((ok=read_pw(buf,buff,BUFSIZ,prompt,verify)) == 0)
 		des_string_to_2keys(buf,key1,key2);
-	bzero(buf,BUFSIZ);
-	bzero(buff,BUFSIZ);
+	memset(buf,0,BUFSIZ);
+	memset(buff,0,BUFSIZ);
 	return(ok);
 	}
 
-int des_read_pw_string(buf,length,prompt,verify)
+int des_read_pw_string(buf, length, prompt, verify)
 char *buf;
 int length;
 char *prompt;
@@ -105,7 +160,7 @@ int verify;
 	int ret;
 
 	ret=read_pw(buf,buff,(length>BUFSIZ)?BUFSIZ:length,prompt,verify);
-	bzero(buff,BUFSIZ);
+	memset(buff,0,BUFSIZ);
 	return(ret);
 	}
 
@@ -117,12 +172,13 @@ FILE *in;
 
 	do	{
 		fgets(buf,SIZE,in);
-		} while (index(buf,'\n') == NULL);
+		} while (strchr(buf,'\n') == NULL);
 	}
 
 /* return 0 if ok, 1 (or -1) otherwise */
-static int read_pw(buf,buff,size,prompt,verify)
-char *buf,*buff;
+static int read_pw(buf, buff, size, prompt, verify)
+char *buf;
+char *buff;
 int size;
 char *prompt;
 int verify;
@@ -139,9 +195,9 @@ int verify;
 	unsigned short channel = 0;
 #endif
 	int ok=0;
-	char *p;
 	int ps=0;
-	FILE *tty;
+	FILE *tty=NULL;
+	char *p;
 
 #ifndef MSDOS
 	if ((tty=fopen("/dev/tty","r")) == NULL)
@@ -154,7 +210,7 @@ int verify;
 #ifdef TIOCGETP
 	if (ioctl(fileno(tty),TIOCGETP,(char *)&tty_orig) == -1)
 		return(-1);
-	bcopy(&(tty_orig),&(tty_new),sizeof(tty_orig));
+	memcpy(&(tty_new),&(tty_orig),sizeof(tty_orig));
 #endif
 #else /* VMS */
 	status = SYS$ASSIGN(&terminal,&channel,0,0);
@@ -198,7 +254,7 @@ int verify;
 		buf[0]='\0';
 		fgets(buf,size,tty);
 		if (feof(tty)) goto error;
-		if ((p=(char *)index(buf,'\n')) != NULL)
+		if ((p=(char *)strchr(buf,'\n')) != NULL)
 			*p='\0';
 		else	read_till_nl(tty);
 		if (verify)
@@ -208,7 +264,7 @@ int verify;
 			buff[0]='\0';
 			fgets(buff,size,tty);
 			if (feof(tty)) goto error;
-			if ((p=(char *)index(buff,'\n')) != NULL)
+			if ((p=(char *)strchr(buff,'\n')) != NULL)
 				*p='\0';
 			else	read_till_nl(tty);
 				
@@ -259,9 +315,13 @@ static void popsig()
 		signal(i,savsig[i]);
 	}
 
-static void recsig()
+static void recsig(i)
+int i;
 	{
 	longjmp(save,1);
+#ifdef LINT
+	i=i;
+#endif
 	}
 
 #ifdef MSDOS
@@ -270,7 +330,7 @@ char *buf;
 int size;
 FILE *tty;
 	{
-	int i;
+	int i,n;
 	char *p;
 
 	p=buf;
@@ -291,5 +351,6 @@ FILE *tty;
 			break;
 			}
 		}
+	return(strlen(buf));
 	}
 #endif
